==> webkitgtk-2.7.2.tar.xz: webkitgtk-2.7.2/Source/JavaScriptCore/inspector/InspectorAgentBase.h <==
/*
 * Copyright (C) 2013 Apple Inc. All Rights Reserved.
 * Copyright (C) 2011 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef InspectorAgentBase_h
#define InspectorAgentBase_h

#include <wtf/text/WTFString.h>

namespace Inspector {

class InspectorBackendDispatcher;
class InspectorFrontendChannel;

enum class InspectorDisconnectReason {
    InspectedTargetDestroyed,
    InspectorDestroyed
};

class InspectorAgentBase {
public:
    virtual ~InspectorAgentBase() { }

    String domainName() const { return m_name; }

    virtual void didCreateFrontendAndBackend(InspectorFrontendChannel*, InspectorBackendDispatcher*) = 0;
    virtual void willDestroyFrontendAndBackend(InspectorDisconnectReason reason) = 0;
    virtual void discardAgent() { }

protected:
    InspectorAgentBase(const String& name)
        : m_name(name)
    {
    }

    String m_name;
};
    
} // namespace Inspector

#endif // !defined(InspectorAgentBase_h)

==> webkitgtk-2.14.2.tar.xz: webkitgtk-2.14.2/Source/JavaScriptCore/inspector/InspectorAgentBase.h <==
/*
 * Copyright (C) 2013, 2015 Apple Inc. All Rights Reserved.
 * Copyright (C) 2011 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <wtf/text/WTFString.h>

namespace JSC {
class JSGlobalObject;
}

namespace Inspector {

class BackendDispatcher;
class FrontendRouter;
class InjectedScriptManager;
class InspectorEnvironment;

struct AgentContext {
    InspectorEnvironment& environment;
    InjectedScriptManager& injectedScriptManager;
    FrontendRouter& frontendRouter;
    BackendDispatcher& backendDispatcher;
};

struct JSAgentContext : public AgentContext {
    JSAgentContext(AgentContext& context, JSC::JSGlobalObject& globalObject)
        : AgentContext(context)
        , inspectedGlobalObject(globalObject)
    {
    }

    JSC::JSGlobalObject& inspectedGlobalObject;
};

enum class DisconnectReason {
    InspectedTargetDestroyed,
    InspectorDestroyed
};

class InspectorAgentBase {
    WTF_MAKE_FAST_ALLOCATED;
public:
    virtual ~InspectorAgentBase() { }

    String domainName() const { return m_name; }

    virtual void didCreateFrontendAndBackend(FrontendRouter*, BackendDispatcher*) = 0;
    virtual void willDestroyFrontendAndBackend(DisconnectReason) = 0;
    virtual void discardAgent() { }

protected:
    InspectorAgentBase(const String& name)
        : m_name(name)
    {
    }

    String m_name;
};

} // namespace Inspector
